==> tikiwiki-10.2.txz: usr/local/www/tikiwiki-10.2/lang/ca/language.js <==
/* 
 * Javascript translation definition
 * Example in Catalan
 * 
 * $Id: language.js 41820 2012-06-06 18:11:59Z robertplummer $
 */

lang = {
	"Very Secure" : "Molt segura",
	"Secure" : "Segura",
	"Very Strong" : "Molt forta",
	"Strong" : "Forta",
	"Average" : "Intermitja",
	"Weak" : "Fluixa",
	"Very Weak" : "Molt fluixa",
	"Strength" : "Força",
	"Valid User Name" : "Nom d'usuari vàlid",
	"Passwords match" : "Les contrasenyes coincideixen",
	"Valid Email" : "Correu-e vàlid",
	"Close" : "Tancar",
	"Submit" : "Enviar",
	"Insert" : "Inserir",
	"Replace" : "Substituir",
	"Match" : "Igual",
	"Do not match" : "Diferent",
	"Advanced options" : "Opcions avançades",
	"Pick a file." : "Escull un arxiu",
	"Add Field" : "Afegeix un camp",
	"Edit Field" : "Modifica un camp",
	"Removing the field will result in data loss. Are you sure?" : "La supressió del camp comportarà supressió de dades. N'estàs segur/a?",
	"Save" : "Desa-ho",
	"Cancel" : "Cancel·la-ho",
	"Delete" : "Suprimeix-ho",	
	"Unassign module" : "Deassigna el mòdul",
	"Edit module" : "Modifica el mòdul",
	"Edit module:" : "Modifica el mòdul:",
	"Favorite" : "Favorit",
	"What address are you looking for?" : "Quina adreça estàs cercant?",
	"Filter:" : "Filtre:",
	"Please enter a page name" : "Si us plau, introdueix un nom de pàgina",
	"Change Highlighter" : "Canvia el Ressaltador",
	"Toggle Highlighter" : "Commuta el Ressaltador",
	"Are you sure you want to unassign this module?" : "N'estàs segur que vols desassignar aquest mòdul?"
	// remember the IE does not support ending comma on last item
};

==> tikiwiki-15.0.txz: usr/local/www/tikiwiki-15.0/lang/ca/language.js <==
/* 
 * Javascript translation definition
 * Example in Catalan
 * 
 * $Id: language.js 46278 2013-06-11 10:43:36Z jonnybradley $
 */

lang = {
	"Default" : "Per omissió",
	"Very Secure" : "Molt Segura",
	"Secure" : "Segura",
	"Very Strong" : "Molt forta",
	"Strong" : "Forta",
	"Average" : "Intermitja",
	"Weak" : "Fluixa",
	"Very Weak" : "Molt fluixa",
	"Strength" : "Força",
	"Valid User Name" : "Nom d'usuari vàlid",
	"Passwords match" : "Les contrasenyes coincideixen",
	"Valid Email" : "Correu-e vàlid",
	"Close" : "Tancar",
	"Submit" : "Enviar",
	"Insert" : "Inserir",
	"Replace" : "Substituir",
	"Match" : "Igual",
	"Do not match" : "Diferent",
	"Advanced options" : "Opcions avançades",
	"Pick a file." : "Escull un arxiu",
	"Add Field" : "Afegeix un camp",
	"Edit Field" : "Modifica un camp",
	"Removing the field will result in data loss. Are you sure?" : "La supressió del camp comportarà supressió de dades. N'estàs segur/a?",
	"Save" : "Desa-ho",
	"Cancel" : "Cancel·la-ho",
	"Delete" : "Suprimeix-ho",	
	"Unassign module" : "Deassigna el mòdul",
	"Edit module" : "Modifica el mòdul",
	"Edit module:" : "Modifica el mòdul:",
	"Favorite" : "Favorit",
	"What address are you looking for?" : "Quina adreça estàs cercant?",
	"Filter:" : "Filtre:",
	"Please enter a page name" : "Si us plau, introdueix un nom de pàgina",
	"Change Highlighter" : "Canvia el Ressaltador",
	"Toggle Highlighter" : "Commuta el Ressaltador",
	"Are you sure you want to unassign this module?" : "N'estàs segur que vols desassignar aquest mòdul?",
	"Search Location" : "Cerca una adreça",
	"To My Location" : "Localitza la meva posició",
	"StreetView is not available at this specific point on the map. Zoom in as needed and make sure to click on a blue line." : "La funció StreetView hi és disponible en aquest punt específic sobre el mapa. Aproxima't amb el zoom el que et calgui i assegura't de fer clic sobre una línia blava.",
	"Browse Files" : "Obre la llista d'arxius",
	// remember the IE does not support ending comma on last item
	 "Bogus entry" : "bogus entry"
};
